<?php

namespace Drupal\twig_field_value\Twig\Extension;

/**
 * Provides field value filters for Twig templates.
 */
class FieldValueExtension extends \Twig_Extension {

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return array(
      new \Twig_SimpleFilter('field_label', [$this, 'getFieldLabel']),
      new \Twig_SimpleFilter('field_value', [$this, 'getFieldValue']),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'twig_field_value';
  }

  /**
   * Twig filter callback: Only return a field's label.
   *
   * @param $build
   *   Render array of a field.
   *
   * @return string
   *   The label of a field. If $build is not a render array of a field, NULL is
   *   returned.
   */
  public function getFieldLabel($build) {
    if (isset($build['#theme']) && $build['#theme'] == 'field') {
      return isset($build['#title']) ? $build['#title'] : NULL;
    }

    return NULL;
  }

  /**
   * Twig filter callback: Only return a field's value(s).
   *
   * @param $build
   *   Render array of a field.
   *
   * @return array
   *   Array of render array(s) of field value(s). If $build is not the render
   *   array of a field, NULL is returned.
   */
  public function getFieldValue($build) {
    if (isset($build['#theme']) && $build['#theme'] == 'field') {
      if (isset($build['#items'])) {
        $element = $build['#items'];
        $items = [];
        $delta = 0;

        while (!empty($element[$delta])) {
          $items[$delta] = $build[$delta];
          $delta++;
        }
        return $items;
      }
    }

    return NULL;
  }
}
